@@ -27,25 +27,25 @@ import sipconfig, PyQt4.pyqtconfig
 
 # These are installation specific values created when PyKDE was configured.
 # 
-kde_version_parts = '4.2.4'.split('.')
+kde_version_parts = '4.3.1'.split('.')
 kde_version_hex = int(kde_version_parts[0])*65536 + int(kde_version_parts[1])*256 + int(kde_version_parts[2])
 _pkg_config = {
     'dist_name':            '',
     'kde_version':          kde_version_hex,
     'kde_version_extra':    '',
     'kde_version_sfx':      '',
-    'kde_version_str':      '4.2.4',
+    'kde_version_str':      '4.3.1',
     'kdebasedir':           '/opt/kde',
     'kdeincdir':            '/opt/kde/include',
     'kdelibdir':            '/opt/kde/lib',
     'konsolepart':          'False',
     'libdir':               'lib',
-    'pykde_kde_sip_flags':  ' -t ALL -t WS_X11 -t Qt_4_4_1  -X VendorID -X PyQt_NoPrintRangeBug -g',
+    'pykde_kde_sip_flags':  ' -t ALL -t WS_X11 -t Qt_4_5_0  -X VendorID -X PyQt_NoPrintRangeBug -g',
     'pykde_mod_dir':        '/usr/lib/python2.6/site-packages/PyKDE4',
-    'pykde_modules':        'kdecore solid kdeui kio kutils kparts ktexteditor dnssd phonon plasma soprano nepomuk akonadi',
+    'pykde_modules':        'kdecore solid kdeui kio kutils kparts ktexteditor dnssd phonon plasma soprano nepomuk akonadi polkitqt',
     'pykde_sip_dir':        '/usr/share/sip/PyKDE4',
     'pykde_version':        kde_version_hex,
-    'pykde_version_str':    '4.2.4'
+    'pykde_version_str':    '4.3.1'
 }
 
 _default_macros = None
